@@ -36,3 +36,6 @@ exclude_patterns = []
 
 html_theme = 'sphinx_rtd_theme'
 html_static_path = ['_static']
+
+# API documentation ordering
+autodoc_member_order = 'bysource'
